@@ -1,11 +1,11 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Colin Leroy <colin@colino.net> 
+ * Copyright (C) 1999-2012 Colin Leroy <colin@colino.net> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,21 +14,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
 #ifndef __SSL_CERTWINDOW_H__
 #define __SSL_CERTWINDOW_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
-#if USE_OPENSSL
-
-#include <openssl/ssl.h>
-#include <openssl/objects.h>
+#ifdef USE_GNUTLS
 #include <glib.h>
 #include <gtk/gtk.h>
 #include "ssl_certificate.h"
@@ -36,5 +33,5 @@
 void sslcertwindow_show_cert(SSLCertificate *cert);
 void sslcertwindow_register_hook(void);
 
-#endif /* USE_OPENSSL */
+#endif /* USE_GNUTLS */
 #endif /* __SSL_CERTWINDOW_H__ */
